CREATE TABLE SYS_DICT (
        CODE TEXT NOT NULL,
        BCODE TEXT,
        DICT_CODE TEXT NOT NULL,
        CAPTION TEXT NOT NULL,
        FULL_CAPTION TEXT,
        SHORT_CUT TEXT,
        REMARK TEXT,
        READONLY CHAR(1) NOT NULL,
        ACTIVE CHAR(1) NOT NULL);
ALTER TABLE SYS_DICT ADD PRIMARY KEY (DICT_CODE,CODE);
COMMENT ON TABLE SYS_DICT IS '数据字典表';
COMMENT ON COLUMN SYS_DICT.CODE IS '字典项编码';
COMMENT ON COLUMN SYS_DICT.BCODE IS '字典项编码(业务编码)';
COMMENT ON COLUMN SYS_DICT.DICT_CODE IS '字典编码';
COMMENT ON COLUMN SYS_DICT.CAPTION IS '字典项显示';
COMMENT ON COLUMN SYS_DICT.FULL_CAPTION IS '字典项显示(全)';
COMMENT ON COLUMN SYS_DICT.SHORT_CUT IS '助记码';
COMMENT ON COLUMN SYS_DICT.REMARK IS '备注';
COMMENT ON COLUMN SYS_DICT.READONLY IS '是否只读';
COMMENT ON COLUMN SYS_DICT.ACTIVE IS '是否有效';

CREATE TABLE NOTICE (
        CNT TEXT,
        MODIFIER CHAR(32) NOT NULL,
        MODIFY_TIME CHAR(14) NOT NULL);
COMMENT ON TABLE NOTICE IS '系统公告';
COMMENT ON COLUMN NOTICE.CNT IS '备注';
COMMENT ON COLUMN NOTICE.MODIFIER IS '最后修改人ID';
COMMENT ON COLUMN NOTICE.MODIFY_TIME IS '最后修改时间（YYYYMMDDHH24MISS）,初始值:20000101010101';

CREATE TABLE LUSER (
        ACTIVE CHAR(1) NOT NULL,
        PASSWD TEXT NOT NULL,
        ID CHAR(32) NOT NULL,
        NAME TEXT NOT NULL,
        ACCOUNT TEXT NOT NULL,
        COMP TEXT NOT NULL,
        JOB TEXT NOT NULL,
        PHONE TEXT,
        EMAIL TEXT,
        REMARK TEXT,
        TYPE INTEGER NOT NULL,
        CREATE_TIME CHAR(14) NOT NULL,
        MODIFY_TIME CHAR(14) NOT NULL,
        CREATOR CHAR(32) NOT NULL,
        MODIFIER CHAR(32) NOT NULL);
ALTER TABLE LUSER ADD PRIMARY KEY (ID);
ALTER TABLE LUSER ADD UNIQUE (ACCOUNT);
COMMENT ON TABLE LUSER IS '用户表';
COMMENT ON COLUMN LUSER.ACTIVE IS '是否可用';
COMMENT ON COLUMN LUSER.PASSWD IS '密码（MD5）';
COMMENT ON COLUMN LUSER.ID IS '用户ID';
COMMENT ON COLUMN LUSER.NAME IS '用户姓名';
COMMENT ON COLUMN LUSER.ACCOUNT IS '用户帐号';
COMMENT ON COLUMN LUSER.COMP IS '用户所属单位';
COMMENT ON COLUMN LUSER.JOB IS '用户职位';
COMMENT ON COLUMN LUSER.PHONE IS '联系电话';
COMMENT ON COLUMN LUSER.EMAIL IS '联系邮件';
COMMENT ON COLUMN LUSER.REMARK IS '备注';
COMMENT ON COLUMN LUSER.TYPE IS '账户类型';
COMMENT ON COLUMN LUSER.CREATE_TIME IS '创建时间（YYYYMMDDHH24MISS）不可修改';
COMMENT ON COLUMN LUSER.MODIFY_TIME IS '最后修改时间（YYYYMMDDHH24MISS）,初始值:20000101010101';
COMMENT ON COLUMN LUSER.CREATOR IS '创建人ID';
COMMENT ON COLUMN LUSER.MODIFIER IS '最后修改人ID';


CREATE TABLE BRIDGE (
        ID CHAR(32) NOT NULL,
        ACTIVE CHAR(1) NOT NULL,
        CODE TEXT NOT NULL,
        SHORT_NAME TEXT NOT NULL,
        NAME TEXT NOT NULL,
        ADDR_CODE TEXT NOT NULL,
        SERVICE_DAY TEXT NOT NULL,
        LOCATION TEXT NOT NULL,
        DESCP TEXT,
        REMARK TEXT,
        IMG TEXT NOT NULL,
        ORG TEXT NOT NULL,
        PHONE TEXT NOT NULL,
        EMAIL TEXT NOT NULL,
        CREATE_TIME CHAR(14) NOT NULL,
        MODIFY_TIME CHAR(14) NOT NULL,
        CREATOR CHAR(32) NOT NULL,
        MODIFIER CHAR(32) NOT NULL);
ALTER TABLE BRIDGE ADD PRIMARY KEY (ID);
ALTER TABLE BRIDGE ADD UNIQUE (SHORT_NAME);
ALTER TABLE BRIDGE ADD UNIQUE (NAME);
COMMENT ON TABLE BRIDGE IS '桥梁信息';
COMMENT ON COLUMN BRIDGE.ID IS 'id';
COMMENT ON COLUMN BRIDGE.ACTIVE IS '是否可用';
COMMENT ON COLUMN BRIDGE.CODE IS '桥梁编号';
COMMENT ON COLUMN BRIDGE.SHORT_NAME IS '桥梁简称';
COMMENT ON COLUMN BRIDGE.NAME IS '桥梁名称（全称）';
COMMENT ON COLUMN BRIDGE.ADDR_CODE IS '桥梁政区划编码';
COMMENT ON COLUMN BRIDGE.SERVICE_DAY IS '桥梁开通日期（YYYYMMDD）';
COMMENT ON COLUMN BRIDGE.LOCATION IS '桥梁定位';
COMMENT ON COLUMN BRIDGE.DESCP IS '桥梁详细描述';
COMMENT ON COLUMN BRIDGE.REMARK IS '桥梁备注';
COMMENT ON COLUMN BRIDGE.ORG IS '桥梁维护机构名称';
COMMENT ON COLUMN BRIDGE.PHONE IS '桥梁维护机构电话';
COMMENT ON COLUMN BRIDGE.EMAIL IS '桥梁维护机构电邮';
COMMENT ON COLUMN BRIDGE.CREATE_TIME IS '创建时间（YYYYMMDDHH24MISS）不可修改';
COMMENT ON COLUMN BRIDGE.MODIFY_TIME IS '最后修改时间（YYYYMMDDHH24MISS）,初始值:20000101010101';
COMMENT ON COLUMN BRIDGE.CREATOR IS '创建人ID';
COMMENT ON COLUMN BRIDGE.MODIFIER IS '最后修改人ID';


CREATE TABLE USER_BRIDGE (
        UID TEXT NOT NULL,
        BRIDGE TEXT NOT NULL);
COMMENT ON TABLE USER_BRIDGE IS '用户桥梁';
COMMENT ON COLUMN USER_BRIDGE.UID IS '用户ID';
COMMENT ON COLUMN USER_BRIDGE.BRIDGE IS '桥梁ID';

CREATE TABLE BRIDGE_SERVER (
        ID CHAR(32) NOT NULL,
        SEQ TEXT NOT NULL,
        ACTIVE CHAR(1) NOT NULL,
        CODE TEXT NOT NULL,
        BRIDGE_ID TEXT NOT NULL,
        IP TEXT NOT NULL,
        DEVICES INTEGER NOT NULL,
        REMARK TEXT,
        CREATE_TIME CHAR(14) NOT NULL,
        MODIFY_TIME CHAR(14) NOT NULL,
        CREATOR CHAR(32) NOT NULL,
        MODIFIER CHAR(32) NOT NULL);
ALTER TABLE BRIDGE_SERVER ADD PRIMARY KEY (ID);
COMMENT ON TABLE BRIDGE_SERVER IS '采集服务器';
COMMENT ON COLUMN BRIDGE_SERVER.ID IS 'id';
COMMENT ON COLUMN BRIDGE_SERVER.SEQ IS '内部编号';
COMMENT ON COLUMN BRIDGE_SERVER.ACTIVE IS '是否可用';
COMMENT ON COLUMN BRIDGE_SERVER.CODE IS '采集服务器编号';
COMMENT ON COLUMN BRIDGE_SERVER.BRIDGE_ID IS '采集服务器所属桥梁Id';
COMMENT ON COLUMN BRIDGE_SERVER.IP IS '采集服务器IP';
COMMENT ON COLUMN BRIDGE_SERVER.DEVICES IS '采集盒数量';
COMMENT ON COLUMN BRIDGE_SERVER.REMARK IS '备注';
COMMENT ON COLUMN BRIDGE_SERVER.CREATE_TIME IS '创建时间（YYYYMMDDHH24MISS）不可修改';
COMMENT ON COLUMN BRIDGE_SERVER.MODIFY_TIME IS '最后修改时间（YYYYMMDDHH24MISS）,初始值:20000101010101';
COMMENT ON COLUMN BRIDGE_SERVER.CREATOR IS '创建人ID';
COMMENT ON COLUMN BRIDGE_SERVER.MODIFIER IS '最后修改人ID';

CREATE TABLE COLLECT_DEVICE (
        ID CHAR(32) NOT NULL,
        SEQ INTEGER NOT NULL,
        CODE TEXT NOT NULL,
        SERVER_ID TEXT NOT NULL,
        CHANNELS INTEGER NOT NULL,
        REMARK TEXT,
        ACTIVE CHAR(1) NOT NULL,
        CREATE_TIME CHAR(14) NOT NULL,
        MODIFY_TIME CHAR(14) NOT NULL,
        CREATOR CHAR(32) NOT NULL,
        MODIFIER CHAR(32) NOT NULL);
ALTER TABLE COLLECT_DEVICE ADD PRIMARY KEY (ID);
COMMENT ON TABLE COLLECT_DEVICE IS '采集盒';
COMMENT ON COLUMN COLLECT_DEVICE.ID IS 'id';
COMMENT ON COLUMN COLLECT_DEVICE.SEQ IS '内部编号';
COMMENT ON COLUMN COLLECT_DEVICE.CODE IS '采集盒编号';
COMMENT ON COLUMN COLLECT_DEVICE.SERVER_ID IS '采集盒所属服务器ID';
COMMENT ON COLUMN COLLECT_DEVICE.CHANNELS IS '采集盒信道数量';
COMMENT ON COLUMN COLLECT_DEVICE.REMARK IS '备注';
COMMENT ON COLUMN COLLECT_DEVICE.ACTIVE IS '是否可用';
COMMENT ON COLUMN COLLECT_DEVICE.CREATE_TIME IS '创建时间（YYYYMMDDHH24MISS）不可修改';
COMMENT ON COLUMN COLLECT_DEVICE.MODIFY_TIME IS '最后修改时间（YYYYMMDDHH24MISS）,初始值:20000101010101';
COMMENT ON COLUMN COLLECT_DEVICE.CREATOR IS '创建人ID';
COMMENT ON COLUMN COLLECT_DEVICE.MODIFIER IS '最后修改人ID';


CREATE TABLE TRANSDUCER (
        ID CHAR(32) NOT NULL,
        SEQ INTEGER NOT NULL,
        CODE TEXT NOT NULL,
        DEVICE_ID TEXT NOT NULL,
        CABLE_TYPE TEXT NOT NULL,
        LOC_TYPE TEXT NOT NULL,
        REMARK TEXT,
        ACTIVE CHAR(1) NOT NULL,
        CREATE_TIME CHAR(14) NOT NULL,
        MODIFY_TIME CHAR(14) NOT NULL,
        CREATOR CHAR(32) NOT NULL,
        MODIFIER CHAR(32) NOT NULL);
ALTER TABLE TRANSDUCER ADD PRIMARY KEY (ID);
COMMENT ON TABLE TRANSDUCER IS '传感器';
COMMENT ON COLUMN TRANSDUCER.ID IS 'id';
COMMENT ON COLUMN TRANSDUCER.SEQ IS '内部编号';
COMMENT ON COLUMN TRANSDUCER.CODE IS '采集盒编号';
COMMENT ON COLUMN TRANSDUCER.DEVICE_ID IS '传感器编号';
COMMENT ON COLUMN TRANSDUCER.CABLE_TYPE IS '传感器所在主缆(dict)';
COMMENT ON COLUMN TRANSDUCER.LOC_TYPE IS '传感器所在位置(dict)';
COMMENT ON COLUMN TRANSDUCER.REMARK IS '备注';
COMMENT ON COLUMN TRANSDUCER.ACTIVE IS '是否可用';
COMMENT ON COLUMN TRANSDUCER.CREATE_TIME IS '创建时间（YYYYMMDDHH24MISS）不可修改';
COMMENT ON COLUMN TRANSDUCER.MODIFY_TIME IS '最后修改时间（YYYYMMDDHH24MISS）,初始值:20000101010101';
COMMENT ON COLUMN TRANSDUCER.CREATOR IS '创建人ID';
COMMENT ON COLUMN TRANSDUCER.MODIFIER IS '最后修改人ID';

CREATE TABLE ALARM_DATA_ITEM (
        ID TEXT NOT NULL,
        SEQ INTEGER NOT NULL,
        STIME TEXT NOT NULL,
        ATIME TEXT NOT NULL,
        DATA TEXT NOT NULL);
ALTER TABLE ALARM_DATA_ITEM ADD PRIMARY KEY (ID,SEQ);
COMMENT ON TABLE ALARM_DATA_ITEM IS '报警数据';
COMMENT ON COLUMN ALARM_DATA_ITEM.ID IS '报警编号';
COMMENT ON COLUMN ALARM_DATA_ITEM.SEQ IS '传感内部编号';
COMMENT ON COLUMN ALARM_DATA_ITEM.STIME IS '起始时间';
COMMENT ON COLUMN ALARM_DATA_ITEM.ATIME IS '报警时间';
COMMENT ON COLUMN ALARM_DATA_ITEM.DATA IS '报警数据，共300个数据点，以英文逗号分隔';


CREATE TABLE ALARM_MSG (
        UID CHAR(32) NOT NULL,
        AID TEXT NOT NULL,
        SERVER TEXT NOT NULL,
        DEVICE INTEGER NOT NULL,
        READED CHAR(1) NOT NULL,
        READ_TIME TEXT,
        CREATE_TIME CHAR(14) NOT NULL,
        ALARM_TIME TEXT NOT NULL);
ALTER TABLE ALARM_MSG ADD PRIMARY KEY (UID,AID);
COMMENT ON TABLE ALARM_MSG IS '报警消息';
COMMENT ON COLUMN ALARM_MSG.UID IS '用户ID';
COMMENT ON COLUMN ALARM_MSG.AID IS '报警ID';
COMMENT ON COLUMN ALARM_MSG.SERVER IS '采集服务器内部编号';
COMMENT ON COLUMN ALARM_MSG.DEVICE IS '采集盒内部编号';
COMMENT ON COLUMN ALARM_MSG.READED IS '是否已读';
COMMENT ON COLUMN ALARM_MSG.READ_TIME IS '读取时间';
COMMENT ON COLUMN ALARM_MSG.CREATE_TIME IS '创建时间（YYYYMMDDHH24MISS）不可修改';
COMMENT ON COLUMN ALARM_MSG.ALARM_TIME IS '报警时间';


CREATE TABLE WAVE_DATA_ITEM (
        SEQ TEXT NOT NULL,
        CTIME TEXT NOT NULL,
        DID INTEGER NOT NULL,
        CID INTEGER NOT NULL,
        HVALUE INTEGER NOT NULL,
        LVALUE INTEGER NOT NULL);
ALTER TABLE WAVE_DATA_ITEM ADD PRIMARY KEY (CTIME,SEQ,DID,CID);
COMMENT ON TABLE WAVE_DATA_ITEM IS '监控历史数据';
COMMENT ON COLUMN WAVE_DATA_ITEM.SEQ IS '采集服务器内部编号';
COMMENT ON COLUMN WAVE_DATA_ITEM.CTIME IS '上传时间（YYYYMMDDHH24MISS';
COMMENT ON COLUMN WAVE_DATA_ITEM.DID IS '采集盒内部编号';
COMMENT ON COLUMN WAVE_DATA_ITEM.CID IS '传感器内部编号';
COMMENT ON COLUMN WAVE_DATA_ITEM.HVALUE IS '一秒内最大幅度值';
COMMENT ON COLUMN WAVE_DATA_ITEM.LVALUE IS '一秒内最小幅度值';



INSERT INTO LUSER (active, passwd, id, name,account, comp,job,phone,email,remark,type, create_time,modify_time, creator, modifier) 
VALUES 
('1', 'E10ADC3949BA59ABBE56E057F20F883E', '77005D20EAB44360918AFD2EA5B867AE', 'admin', '18888888888', 'kexiu', 'a', '18888888888', 
'admin@ekexiu.com', NULL, '1', '20180801123001', '20000101010101', '77005D20EAB44360918AFD2EA5B867AE', '77005D20EAB44360918AFD2EA5B867AE');

INSERT INTO sys_dict (code, bcode, dict_code, caption, full_caption, short_cut, remark, readonly, active) VALUES ('01', NULL, 'ZLLX', '上游主缆', NULL, NULL, NULL, '0', '1');
INSERT INTO sys_dict (code, bcode, dict_code, caption, full_caption, short_cut, remark, readonly, active) VALUES ('02', NULL, 'ZLLX', '下游主缆', NULL, NULL, NULL, '0', '1');
INSERT INTO sys_dict (code, bcode, dict_code, caption, full_caption, short_cut, remark, readonly, active) VALUES ('01', NULL, 'ZLWZ', '东跨', NULL, NULL, NULL, '0', '1');
INSERT INTO sys_dict (code, bcode, dict_code, caption, full_caption, short_cut, remark, readonly, active) VALUES ('02', NULL, 'ZLWZ', '西跨', NULL, NULL, NULL, '0', '1');

CREATE TABLE ALARM_DATA_ERROR (
        CNT TEXT NOT NULL,
        RTIME BIGINT NOT NULL,
        REASON TEXT NOT NULL);
COMMENT ON TABLE ALARM_DATA_ERROR IS '报警数据错误表';
COMMENT ON COLUMN ALARM_DATA_ERROR.CNT IS '接口数据';
COMMENT ON COLUMN ALARM_DATA_ERROR.RTIME IS '接口数据接收时间';
COMMENT ON COLUMN ALARM_DATA_ERROR.REASON IS '接口数据错误原因';

CREATE TABLE WAVE_DATA_ERROR (
        CNT TEXT NOT NULL,
        RTIME BIGINT NOT NULL,
        REASON TEXT NOT NULL);
COMMENT ON TABLE WAVE_DATA_ERROR IS '实时数据错误表';
COMMENT ON COLUMN WAVE_DATA_ERROR.CNT IS '接口数据';
COMMENT ON COLUMN WAVE_DATA_ERROR.RTIME IS '接口数据接收时间';
COMMENT ON COLUMN WAVE_DATA_ERROR.REASON IS '接口数据错误原因';

INSERT INTO notice(cnt,modifier,modify_time) VALUES ('欢迎使用本系统！', '111                             ', '20180101010101');
